@@ -14,14 +14,17 @@
 
 define('io.ox/tours/intro', [
     'io.ox/core/extensions',
-    'io.ox/core/notifications',
     'io.ox/core/capabilities',
     'io.ox/core/tk/wizard',
-    'gettext!io.ox/tours'
-], function (ext, notifications, capabilities, Tour, gt) {
+    'settings!io.ox/tours',
+    'gettext!io.ox/tours',
+    'io.ox/tours/whats-new'
+], function (ext, capabilities, Tour, settings, gt) {
 
     'use strict';
 
+    var whatsNewPoint = ext.point('io.ox/tours/whats_new');
+
     /* Tour: intro. The special one that does not belong to an app */
     Tour.registry.add({
         id: 'default/io.ox/intro'
@@ -29,32 +32,30 @@ define('io.ox/tours/intro', [
         //Tour needs webmail and should be disabled for guests (See Bug 40545)
         if (!capabilities.has('webmail && !guest')) return;
 
-        new Tour()
+        var tour = new Tour()
         .step()
             .title(gt.format(gt('Welcome to %s'), ox.serverConfig.productName))
             .content(gt('This guided tour will briefly introduce you to the product. Get more detailed information in the tours for the single apps or in the online help.'))
             .end()
         .step()
             .title(gt('Launching an app'))
-            .content(gt('To launch an app, click on an entry on the left side of the menu bar.'))
-            .hotspot('.launcher[data-app-name="io.ox/mail"]')
-            .referTo('.launcher[data-app-name="io.ox/mail"]')
+            .on('before:show', function () { if ($('.launcher-dropdown:visible').length === 0) $('#io-ox-launcher .btn').first().click(); })
+            .content(gt('To launch an app, use the quick launch icons on the left side of the menu bar or click on an entry inside the app launcher menu.'))
+            .hotspot('#io-ox-launchgrid')
+            .referTo('#io-ox-launchgrid')
+            .on('hide', function () { if ($('.launcher-dropdown:visible').length === 1) $('#io-ox-launcher .btn').first().click(); })
             .end()
         .step()
             .title(gt('Displaying the help or the settings'))
             .content(gt('To display the help or the settings, click the System menu icon in the menu bar.'))
-            .hotspot('.launcher .fa-bars.launcher-icon')
+            .hotspot('#io-ox-topbar-dropdown-icon')
             .referTo('#topbar-settings-dropdown')
             .waitFor('#topbar-settings-dropdown')
-            .on('wait', function () {
-                $('#topbar-settings-dropdown').css('display', 'block');
-            })
-            .on('hide', function () {
-                $('#topbar-settings-dropdown').css('display', '');
-            })
-            .on('before:show', function () { notifications.hide(); })
+            .on('wait', function () { $('#io-ox-topbar-dropdown-icon .dropdown-toggle').click(); })
+            .on('hide', function () { $('#io-ox-topbar-dropdown-icon .dropdown-toggle').click(); })
             .end()
-        .step()
+        // notification area is not always shown in new topbar
+        /*.step()
             .title(gt('The New objects icon'))
             .content(gt('The New objects icon shows the number of appointment reminders or other notifications. If clicking the icon, the info area opens.'))
             .hotspot('#io-ox-notifications-icon')
@@ -67,15 +68,14 @@ define('io.ox/tours/intro', [
             .hotspot('#io-ox-notifications-icon')
             .referTo('#io-ox-notifications')
             .on('before:show', function () { notifications.show(); $('#io-ox-notifications').show(); })
-            .end()
+            .end()*/
         .step()
             .title(gt('Creating new items'))
             .content(gt('To create a new E-Mail, click the Compose new E-Mail in the toolbar.'))
             .navigateTo('io.ox/mail/main')
-            .waitFor('.classic-toolbar .io-ox-action-link:first')
-            .hotspot('.classic-toolbar .io-ox-action-link:first')
-            .referTo('.classic-toolbar .io-ox-action-link:first')
-            .on('before:show', function () { notifications.hide(); })
+            .waitFor('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar .io-ox-action-link:visible:first')
+            .hotspot('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar .io-ox-action-link:visible:first')
+            .referTo('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar .io-ox-action-link:visible:first')
             .end()
         .step()
             .title(gt('Opening or closing the folder tree'))
@@ -93,12 +93,12 @@ define('io.ox/tours/intro', [
         .step()
             .title(gt('Searching for objects'))
             .content(gt('To search for objects, click the Search icon in the menu bar.'))
-            .spotlight('.generic-toolbar.io-ox-find')
+            .spotlight('.search-box')
             .end()
         .step()
             .title(gt('The toolbar'))
             .content(gt('Depending on the app, the toolbar contains various functions for creating, editing and organizing objects.'))
-            .spotlight('.classic-toolbar')
+            .spotlight('.classic-toolbar-container > .classic-toolbar')
             .end()
         .step()
             .title(gt('The folder tree'))
@@ -114,20 +114,30 @@ define('io.ox/tours/intro', [
             .title(gt('The Detail view'))
             .content(gt('The Detail view displays an object\'s content. Depending on the app, further functions for organizing objects can be found in the Detail view.'))
             .spotlight('.mail-detail-pane')
-            .end()
-        .step()
+            .end();
+
+        // integrate what's new tour steps
+        var baton = new ext.Baton({ tour: tour }),
+            list = whatsNewPoint.list(),
+            blackList = ['launcher-icon', 'launcher', 'help'];
+
+        _(list).each(function (step) {
+            if (blackList.indexOf(step.id) !== -1) return;
+            step.invoke('steps', this, baton);
+        });
+
+        // no need to show the what's new tour when the user has already seen the steps here
+        settings.set('whatsNew/autoShow', 0).save();
+
+        tour.step()
             .title(gt('Further information'))
             .content(gt('Detailed instructions for the single apps are located in System menu > Help.'))
             .hotspot('#topbar-settings-dropdown .io-ox-context-help')
             .referTo('#topbar-settings-dropdown')
             .waitFor('#topbar-settings-dropdown')
-            .on('wait', function () {
-                $('#topbar-settings-dropdown').css('display', 'block');
-            })
-            .on('hide', function () {
-                $('#topbar-settings-dropdown').css('display', '');
-            })
+            .on('wait', function () { $('#io-ox-topbar-dropdown-icon .dropdown-toggle').click(); })
+            .on('hide', function () { $('#io-ox-topbar-dropdown-icon .dropdown-toggle').click(); })
             .end()
-        .start();
+            .start();
     });
 });
